@@ -24,7 +24,7 @@ try:
     from StringIO import StringIO
 except ImportError:
     from io import StringIO
-from mock import call
+from unittest.mock import call
 
 from magnumclient import exceptions
 from magnumclient.osc.v1 import clusters as osc_clusters
@@ -125,6 +125,25 @@ class TestClusterCreate(TestCluster):
         self.cmd.take_action(parsed_args)
         self.clusters_mock.create.assert_called_with(**expected_args)
 
+    def test_cluster_create_with_lb_disabled(self):
+        """Verifies master lb disabled properly parsed."""
+
+        expected_args = self._default_args
+        expected_args['master_lb_enabled'] = False
+        arglist = [
+            '--cluster-template', self._cluster.cluster_template_id,
+            '--master-lb-disabled',
+            self._cluster.name
+        ]
+        verifylist = [
+            ('cluster_template', self._cluster.cluster_template_id),
+            ('master_lb_enabled', [False]),
+            ('name', self._cluster.name)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.clusters_mock.create.assert_called_with(**expected_args)
+
 
 class TestClusterDelete(TestCluster):
 
@@ -499,6 +518,21 @@ class TestClusterResize(TestCluster):
             "UUID1", 2, None, None
         )
 
+    def test_cluster_resize_to_zero_pass(self):
+        arglist = ['foo', '0']
+        verifylist = [
+            ('cluster', 'foo'),
+            ('node_count', 0),
+            ('nodes_to_remove', None),
+            ('nodegroup', None)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.clusters_mock.resize.assert_called_with(
+            "UUID1", 0, None, None
+        )
+
 
 class TestClusterUpgrade(TestCluster):
 
